package cn.dg32z.lon.commands;

import cn.dg32z.libs.org.jetbrains.annotations.NotNull;
import cn.dg32z.libs.org.jetbrains.annotations.Nullable;
import cn.dg32z.lon.PluginLoader;
import cn.dg32z.lon.commands.sub.Alerts;
import cn.dg32z.lon.commands.sub.ConsoleDebug;
import cn.dg32z.lon.commands.sub.Control;
import cn.dg32z.lon.commands.sub.Crash;
import cn.dg32z.lon.commands.sub.Debug;
import cn.dg32z.lon.commands.sub.Delay;
import cn.dg32z.lon.commands.sub.Freeze;
import cn.dg32z.lon.commands.sub.Help;
import cn.dg32z.lon.commands.sub.History;
import cn.dg32z.lon.commands.sub.Log;
import cn.dg32z.lon.commands.sub.Mitigate;
import cn.dg32z.lon.commands.sub.Profile;
import cn.dg32z.lon.commands.sub.Reload;
import cn.dg32z.lon.commands.sub.SendAlert;
import cn.dg32z.lon.commands.sub.Setback;
import cn.dg32z.lon.commands.sub.Spectate;
import cn.dg32z.lon.commands.sub.StopSpectate;
import cn.dg32z.lon.commands.sub.UnFreeze;
import cn.dg32z.lon.commands.sub.Verbose;
import cn.dg32z.lon.commands.sub.Version;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Collections;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import org.bukkit.command.CommandSender;
import org.bukkit.command.TabExecutor;
import org.bukkit.entity.Player;

/* loaded from: cn_dg32z_lon_commands.jar:cn/dg32z/lon/commands/MainCommand.class */
public final class MainCommand implements TabExecutor {
    private final Map<String, AbstractCommand> subCommands = new HashMap();

    public MainCommand() {
        registerSubCommand("delay", new Delay());
        registerSubCommand("help", new Help());
        registerSubCommand("setback", new Setback());
        registerSubCommand("control", new Control());
        registerSubCommand("freeze", new Freeze());
        registerSubCommand("unfreeze", new UnFreeze());
        registerSubCommand("version", new Version());
        registerSubCommand("stopspectating", new StopSpectate());
        registerSubCommand("stopspec", new StopSpectate());
        registerSubCommand("spectate", new Spectate());
        registerSubCommand("spec", new Spectate());
        registerSubCommand("verbose", new Verbose());
        registerSubCommand("reload", new Reload());
        registerSubCommand("profile", new Profile());
        registerSubCommand("log", new Log());
        registerSubCommand("logs", new Log());
        registerSubCommand("debug", new Debug());
        registerSubCommand("only-console", new ConsoleDebug());
        registerSubCommand("sendalert", new SendAlert());
        registerSubCommand("alerts", new Alerts());
        registerSubCommand("crash", new Crash());
        registerSubCommand("history", new History());
        registerSubCommand("hist", new History());
        registerSubCommand("mitigate", new Mitigate());
    }

    private void registerSubCommand(String name, AbstractCommand command) {
        this.subCommands.put(name.toLowerCase(), command);
    }

    public boolean onCommand(@NotNull CommandSender sender, @NotNull org.bukkit.command.Command cmd, @NotNull String label, @NotNull String[] args) {
        if (args.length == 0) {
            String message = PluginLoader.INSTANCE.getMessageUtils().i18nWithOutPrefix("commands.help.message");
            sender.sendMessage(message);
            return true;
        }
        String subCommandName = args[0].toLowerCase();
        AbstractCommand subCommand = this.subCommands.get(subCommandName);
        if (subCommand != null) {
            if (subCommand.getPermission() != null && !sender.hasPermission(subCommand.getPermission())) {
                sender.sendMessage(PluginLoader.INSTANCE.getMessageUtils().i18nWithOutPrefix("no-permission"));
                return true;
            }
            if (subCommand.isOnlyPlayer()) {
                if (sender instanceof Player) {
                    Player player = (Player) sender;
                    subCommand.execute(player, label, args);
                    return true;
                }
                sender.sendMessage(PluginLoader.INSTANCE.getMessageUtils().i18n("only-player"));
                return true;
            }
            String[] subArgs = (String[]) Arrays.copyOfRange(args, 1, args.length);
            subCommand.execute(sender, label, subArgs);
            return true;
        }
        sender.sendMessage(PluginLoader.INSTANCE.getMessageUtils().i18n("unknown-command"));
        return true;
    }

    @Nullable
    public List<String> onTabComplete(@NotNull CommandSender sender, @NotNull org.bukkit.command.Command cmd, @NotNull String alias, @NotNull String[] args) {
        if (args.length == 1) {
            List<String> completions = new ArrayList<>();
            String input = args[0].toLowerCase();
            for (String subCommandName : this.subCommands.keySet()) {
                if (sender.hasPermission(this.subCommands.get(subCommandName).getPermission()) && subCommandName.startsWith(input)) {
                    completions.add(subCommandName);
                }
            }
            return completions;
        }
        AbstractCommand subCommand = this.subCommands.get(args[0].toLowerCase());
        if (subCommand != null) {
            String[] subArgs = (String[]) Arrays.copyOfRange(args, 1, args.length);
            return subCommand.onTabComplete(sender, cmd, alias, subArgs);
        }
        return Collections.emptyList();
    }
}
